@@ -2,5 +2,5 @@ class AdmittanceSquaredMixin(object):
 
     quantity = 'admittancesquared'
     quantity_label = 'Admittance^2'
-    units = 'S^2'
+    quantity_units = 'S^2'
     is_admittancesquared = True
