@@ -4,8 +4,9 @@ class CurrentMixin(Quantity):
 
     quantity = 'current'
     quantity_label = 'Current'
-    units = 'A'
+    quantity_units = 'A'
     is_current = True
+    is_signal = True    
 
     def cpt(self):
         from .oneport import I, Idc, Iac
