@@ -19,6 +19,7 @@ from .quantity import UndefinedQuantity
 from .ratfun import Ratfun
 from .sym import sympify, symsimplify, j, omegasym, symdebug, AppliedUndef
 from .sym import capitalize_name, tsym, symsymbol, symbol_map, tausym, nusym, oo
+from .dsym import nsym, ksym, zsym
 from .state import state
 from .printing import pprint, pretty, print_str, latex
 from .functions import sqrt, log10, atan2, gcd, exp, Function
@@ -187,6 +188,20 @@ class ExprDict(ExprPrint, ExprContainer, ExprMisc, OrderedDict):
             new[k] = v
         return new
 
+    @property
+    def expr(self):
+
+        # The behaviour of this may change.  Perhaps the keys
+        # should stay the same?
+        new = {}
+        for k, v in self.items():
+            if isinstance(k, Expr):
+                k = k.expr
+            if isinstance(v, Expr):
+                v = v.expr                
+            new[k] = v
+        return new
+    
     
 class ExprList(ExprPrint, list, ExprContainer, ExprMisc):
     """Decorator class for list created by sympy."""
@@ -218,7 +233,11 @@ class ExprList(ExprPrint, list, ExprContainer, ExprMisc):
         
         return expr([e.subs(*args, **kwargs) for e in self])
         
+    @property
+    def expr(self):
+        return [e.expr for e in self]
 
+    
 class ExprTuple(ExprPrint, tuple, ExprContainer, ExprMisc):
     """Decorator class for tuple created by sympy."""
 
@@ -233,6 +252,9 @@ class ExprTuple(ExprPrint, tuple, ExprContainer, ExprMisc):
         
         return expr((e.subs(*args, **kwargs) for e in self))
 
+    @property
+    def expr(self):
+        return tuple([e.expr for e in self])
     
 class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
     """Decorator class for sympy classes derived from sympy.Expr."""
@@ -378,7 +400,6 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
         except:
             self._units = sym.S.One        
 
-
     def _class_by_quantity(self, quantity, domain=None):
 
         if domain is None:
@@ -591,11 +612,19 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
         self.assumptions.set('unknown', value)        
 
     @property
-    def is_complex(self):
+    def is_complex_signal(self):
+        """Return True if time-domain signal is complex."""
         
-        if 'complex' not in self.assumptions:
+        if 'complex_signal' not in self.assumptions:
             return False
-        return self.assumptions['complex'] == True
+        return self.assumptions['complex_signal'] == True
+
+    @property
+    def is_complex(self):
+        from .sym import ssym
+        from .dsym import zsym        
+        
+        return self.has(j) or self.has(ssym) or self.has(zsym)
 
     @property
     def is_conditional(self):
@@ -856,6 +885,11 @@ As a workaround use x.as_expr() %s y.as_expr()""" % op)
         if (self.is_constant_domain or x.is_constant_domain):
             return True
 
+        # Allow phasor(x) * omega, etc.
+        if (self.is_phasor_domain and x.is_angular_fourier_domain and
+            self.omega == x.var):
+            return True
+        
         return False
 
     def _div_compatible_domains(self, x):
@@ -1545,12 +1579,41 @@ As a workaround use x.as_expr() %s y.as_expr()""" % op)
 
             def sinc(arg):
                 return 1.0 if arg == 0 else np.sin(np.pi * arg) / (np.pi * arg)
+
+            def trap(arg, alpha):
+
+                absarg = abs(arg)
+                foo = absarg - 0.5
+
+                if alpha == 0:
+                    if arg < -0.5 or arg > 0.5:
+                        return 0.0
+                    return 1.0
+            
+                if foo >= 0.5 * alpha:
+                    return 0.0
+                elif foo <= -0.5 * alpha:
+                    return 1.0
+                else:
+                    return 0.5 - foo / alpha
+
+            def tri(arg):
+
+                if arg >= 1:
+                    return 0.0
+                elif arg <= -1:
+                    return 0.0
+                else:
+                    return 1.0 - abs(arg)
             
             def dirac(arg):
                 return np.inf if arg == 0.0 else 0.0
 
             def unitimpulse(arg):
-                return 1.0 if arg == 0 else 0.0            
+                return 1.0 if arg == 0 else 0.0
+
+            def unitstep(arg):
+                return 1.0 if arg >= 0 else 0.0
 
             def heaviside(arg):
                 return 1.0 if arg >= 0.0 else 0.0
@@ -1578,8 +1641,9 @@ As a workaround use x.as_expr() %s y.as_expr()""" % op)
                             ({'DiracDelta' : dirac,
                               'Heaviside' : heaviside,
                               'UnitImpulse' : unitimpulse,
-                              'sinc' : sinc,
-                              'rect' : rect,
+                              'UnitStep' : unitstep,
+                              'sinc' : sinc, 'rect' : rect,
+                              'tri' : tri, 'trap' : trap,
                               'sqrt' : sqrt, 'exp' : exp},
                              "scipy", "numpy", "math", "sympy"))
 
@@ -2576,9 +2640,32 @@ def expr(arg, **assumptions):
         return fexpr(expr, **assumptions)
     elif omegasym in symbols:
         return omegaexpr(expr, **assumptions)
+    elif nsym in symbols:
+        return nexpr(expr, **assumptions)
+    elif ksym in symbols:
+        return kexpr(expr, **assumptions)    
+    elif zsym in symbols:
+        return zexpr(expr, **assumptions)        
     else:
         return cexpr(expr, **assumptions)
 
+    
+def expr_class(domain, arg, **assumptions):
+
+    try:
+        quantity = arg.quantity
+    except:
+        quantity = 'undefined'
+
+    cls = expressionclasses.get_quantity(domain, quantity)
+    return cls
+
+
+def expr_make(domain, arg, **assumptions):
+
+    cls = expr_class(domain, arg)
+    return cls(arg, **assumptions)
+    
 
 def symbol(name, **assumptions):
     """Create an Lcapy symbol.
@@ -2640,6 +2727,9 @@ from .fexpr import f, fexpr, FourierDomainExpression
 from .texpr import t, texpr, TimeDomainExpression
 from .sexpr import s, sexpr, LaplaceDomainExpression
 from .omegaexpr import omega, omegaexpr, AngularFourierDomainExpression
+from .nexpr import nexpr
+from .kexpr import kexpr
+from .zexpr import zexpr
 from .expressionclasses import expressionclasses
 
 # Horrible hack to work with IPython around Sympy's back for LaTeX
