@@ -1,3 +1,4 @@
+
 """
 This module defines the components for modified nodal analysis.  The components
 are defined at the bottom of this file.
@@ -84,7 +85,7 @@ class Cpt(ImmittanceMixin):
 
         # No defined cpt
         if self.type in ('XX', 'Cable'):
-            self.cpt = lcapy.oneport.Dummy()
+            self._cpt = lcapy.oneport.Dummy()
             return
 
         if ((args == () and not self.type in ('W', 'O', 'P'))
@@ -114,9 +115,10 @@ class Cpt(ImmittanceMixin):
             try:
                 newclass = getattr(lcapy.twoport, classname)
             except:
+                self._cpt = lcapy.oneport.Dummy()
                 return
                 
-        self.cpt = newclass(*args)
+        self._cpt = newclass(*args)
 
     def __repr__(self):
         return self.__str__()
@@ -125,6 +127,10 @@ class Cpt(ImmittanceMixin):
         # TODO, use self._netmake() but fix for XX
         return self._string        
 
+    @property
+    def cpt(self):
+        return self._cpt
+    
     def _stamp(self, cct):
         raise NotImplementedError('stamp method not implemented for %s' % self)
 
@@ -396,6 +402,12 @@ class Cpt(ImmittanceMixin):
         else:
             raise ValueError('%s is not a source' % self)        
 
+    @property
+    def is_noiseless(self):
+        """Return True if component is noiseless."""
+
+        return self.cpt.is_noiseless
+        
     @property
     def is_inductor(self):
         """Return True if component is an inductor."""
@@ -796,18 +808,20 @@ class RLC(Cpt):
 
 class RC(RLC):
 
-    def _noisy(self):
+    def _noisy(self, T='T'):
 
         dummy_node = self.dummy_node()
 
         opts = self.opts.copy()
 
-        rnet = self._netmake(nodes=(self.relnodes[0], dummy_node),
-                             opts=opts)                                  
+        # Should check for namespace conflict if user has defined
+        # a noiseless resistor.
+        rnet = self._netmake_variant('N', nodes=(self.relnodes[0], dummy_node),
+                                     args=str(self.R), opts=opts)
 
         # Use k_B for Boltzmann's constant to avoid clash with k symbol
         # for discrete frequency
-        Vn = 'sqrt(4 * k_B * T * %s)' % self.args[0]
+        Vn = 'sqrt(4 * k_B * %s * %s)' % (T, self.args[0])
         vnet = self._netmake_variant('Vn', nodes=(dummy_node, self.relnodes[1]),
                                      args=('noise', Vn), opts=opts)
         return rnet + '\n' + vnet
@@ -1262,6 +1276,13 @@ class R(RC):
     def _r_model(self):    
         return self._copy()
 
+class NR(R):
+
+    add_series = True    
+    
+    def _r_model(self):    
+        return self._copy()    
+
 
 class RV(RC):
 
