@@ -1016,45 +1016,45 @@ class NetlistMixin(object):
             new._add(net)
         return new            
 
-    def _noisy(self, resistornames):
+    def _noisy(self, resistornames, T='T'):
 
         new = self._new()
 
         for cpt in self._elements.values():
             if cpt.name in resistornames:
-                net = cpt._noisy()
+                net = cpt._noisy(T=T)
             else:
                 net = cpt._copy()
             new._add(net)
         return new        
 
-    def noisy_except(self, *args):
+    def noisy_except(self, *args, T='T'):
         """Return a new circuit with all but the specified resistors in series
         with noise voltage sources"""
 
         for arg in args:
-            if arg not in self.elements and self.elements[arg].type != 'R':
+            if arg not in self.elements and not self.elements[arg].is_resistor:
                 raise ValueError('Element %s is not a known resistor' % arg)
         resistors = []
         for cpt in self.elements.values():
-            if cpt.type == 'R' and cpt.name not in args:
+            if cpt.is_resistor and not cpt.is_noiseless and cpt.name not in args:
                 resistors.append(cpt.name)
-        return self._noisy(resistors)
+        return self._noisy(resistors, T)
 
-    def noisy(self, *args):
+    def noisy(self, *args, T='T'):
         """Return a new circuit with the specified resistors in series
         with noise voltage sources"""
 
         if len(args) == 0:
-            return self.noisy_except()
+            return self.noisy_except(T=T)
 
         resistors = []
         for arg in args:
-            if arg not in self.elements and self.elements[arg].type != 'R':
+            if arg not in self.elements and not self.elements[arg].is_resistor:
                 raise ValueError('Element %s is not a known resistor' % arg)
             resistors.append(arg)
 
-        return self._noisy(resistors)
+        return self._noisy(resistors, T=T)
 
     @property
     def cg(self):
@@ -1072,7 +1072,7 @@ class NetlistMixin(object):
 
         names = []
         for name, elt in self.elements.items():
-            if elt.type in ('V', 'I', 'R', 'C', 'L', 'Y', 'Z'):
+            if elt.type in ('V', 'I', 'R', 'NR', 'C', 'L', 'Y', 'Z'):
                 names.append(name)
         return names
 
@@ -1262,7 +1262,7 @@ class NetlistMixin(object):
             for k, subset in subsets.items():
                 if k == 'I':
                     print('Netlist has current sources in series: %s' % subset)
-                elif k in ('R', 'L', 'V', 'Z'):
+                elif k in ('R', 'NR', 'L', 'V', 'Z'):
                     if k == 'L' and not self._check_ic(subset):
                         continue
                     changed |= self._do_simplify_combine('Can add in series: %s',
@@ -1288,7 +1288,7 @@ class NetlistMixin(object):
             for k, subset in subsets.items():
                 if k == 'V':
                     print('Netlist has voltage sources in parallel: %s'% subset)
-                elif k in ('R', 'L', 'Z'):
+                elif k in ('R', 'NR', 'L', 'Z'):
                     changed |= self._do_simplify_combine('Can combine in parallel: %s',
                                                          subset, net, explain, False, False)
                 elif k in ('C', 'Y', 'I'):
@@ -1581,12 +1581,12 @@ class NetlistMixin(object):
         
         return self.s_model(j * var)
 
-    def noise_model(self):
+    def noise_model(self, T='T'):
         """"Create noise model where resistors are converted into a series
         combination of an ideal resistor and a noise voltage
         source."""
         
-        return self.noisy()
+        return self.noisy(T=T)
     
     def draw(self, filename=None, **kwargs):
         """Draw schematic of netlist.
