@@ -1,7 +1,7 @@
 """
 This module performs plotting using matplotlib.
 
-Copyright 2014--2020 Michael Hayes, UCECE
+Copyright 2014--2021 Michael Hayes, UCECE
 """
 
 import numpy as np
@@ -14,8 +14,11 @@ def make_axes(figsize=None, axes=None, **kwargs):
     from matplotlib.pyplot import subplots
     
     if axes is not None:
+        if isinstance(axes, tuple):
+            # FIXME
+            axes = axes[0]
         fig = axes.figure
-    elif figsize is not None :
+    elif figsize is not None:
         fig, axes = subplots(1, figsize=figsize, **kwargs)
     else:
         fig, axes = subplots(1, **kwargs)
@@ -207,6 +210,14 @@ def plot_frequency(obj, f, **kwargs):
     return ax
 
 
+def plot_bode(obj, f, **kwargs):
+
+    if 'log_frequency' not in kwargs:
+        kwargs['log_frequency'] = True
+    
+    return plot_frequency(obj, f, **kwargs)
+
+
 def plot_angular_frequency(obj, omega, **kwargs):
 
     npoints = kwargs.pop('npoints', 400)        
