@@ -10,7 +10,7 @@ from .domains import LaplaceDomain
 from .laplace import inverse_laplace_transform
 from .sym import ssym, tsym, j, pi, sympify
 from .ratfun import _zp2tf, _pr2tf, Ratfun
-from .expr import Expr, symbol, expr, ExprDict, exprcontainer
+from .expr import Expr, symbol, expr, ExprDict, exprcontainer, expr_make
 from .units import u as uu
 from .functions import sqrt
 import numpy as np
@@ -181,7 +181,7 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         """Convert to phasor domain."""
 
         result = PhasorFrequencyDomainExpression.from_laplace(self, **assumptions)
-        return self.change(result, domain='phasor', **assumptions)
+        return result
 
     def transient_response(self, tvector=None):
         """Evaluate transient (impulse) response."""
@@ -318,6 +318,19 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         from .plot import plot_pole_zero
         return plot_pole_zero(self, **kwargs)
 
+    def pole_zero_plot(self, **kwargs):
+        """Plot pole-zero map."""
+
+        return self.plot(**kwargs)
+
+    def bode_plot(self, fvector=None, **kwargs):
+        """Plot frequency response for a frequency-domain phasor as a Bode
+        plot (but without the straight line approximations).  fvector
+        specifies the frequencies.  If it is a tuple (m1, m2), it sets the
+        frequency limits as (10**m1, 10**m2)."""        
+
+        return self.phasor().bode_plot(fvector, **kwargs)
+    
     def parameterize(self, zeta=True):
         """Parameterize first and second-order expressions.
 
@@ -480,7 +493,7 @@ def sexpr(arg, **assumptions):
 
     if arg is ssym:
         return s
-    return LaplaceDomainExpression(arg, **assumptions)
+    return expr_make('laplace', arg, **assumptions)
 
 
 from .expressionclasses import expressionclasses
