@@ -83,4 +83,19 @@ class LcapyTester(unittest.TestCase):
         H2 = h(s)
 
         self.assertEqual(H, H2, "second derivative of undef")                
+
+    def test_laplace_convolution(self):
+
+        a = expr('Integral(3 * x(t - tau) * y(tau), (tau, -oo, oo))')
+        self.assertEqual(a(s), expr('3 * X(s) * Y(s)'), "3 * X * Y")
+        a = expr('Integral(3 * x(tau) * y(t - tau), (tau, -oo, oo))')
+        self.assertEqual(a(s), expr('3 * X(s) * Y(s)'), "3 * X * Y")
+        a = expr('Integral(3 * x(t - tau) * Heaviside(tau), (tau, -oo, oo))')
+        self.assertEqual(a(s), expr('3 * X(s) / s'), "3 * X / s")
+        a = expr('Integral(3 * x(tau) * Heaviside(t - tau), (tau, -oo, oo))')
+        self.assertEqual(a(s), expr('3 * X(s) / s'), "3 * X / s")
+
+        a = expr('Integral(3 * x(t - tau), (tau, 0, oo))')
+        self.assertEqual(a(s), expr('3 * X(s) / s'), "3 * X / s")
         
+ 
