@@ -1,7 +1,7 @@
 from lcapy import *
+from lcapy.phasor import PhasorFrequencyDomainExpression
 import unittest
 
-
 class LcapyTester(unittest.TestCase):
     """Unit tests for lcapy"""
 
@@ -19,7 +19,9 @@ class LcapyTester(unittest.TestCase):
         a = phasor(3, omega=7)
         self.assertEqual(a.omega, 7, 'omega')
         self.assertEqual(a.phase, 0, 'phase')
-        self.assertEqual(a.magnitude, 3, 'magnitude')        
+        self.assertEqual(a.magnitude, 3, 'magnitude')
+        self.assertEqual(a.N, 3, 'N')
+        self.assertEqual(a.D, 1, 'D')                        
         
         a = phasor(-3, omega=7)
         self.assertEqual(a.phase, pi, 'phase')                
@@ -42,11 +44,25 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(V, V2, 'phasorvoltage')
         self.assertEqual(I, I2, 'phasorcurrent')                
         
-
     def test_phasor_rms(self):        
 
         p = phasor(2)
         
         self.assertEqual(p.rms(), sqrt(2), 'rms')
+
+    def test_phasor_mul_omega(self):
+
+        p = phasor(2)
+        q = p * omega
+        r = phasor(2 * omega)
+
+        self.assertEqual(q, r, 'phasor(2) * omega')        
         
+    def test_phasor_transform(self):
+
+        H = 1 / s
+        P = H(jw)
+
+        self.assertEqual(type(P), PhasorFrequencyDomainExpression, 'H(jw)')
+
         
