@@ -1,4 +1,6 @@
 from lcapy import *
+from lcapy.voltage import Vname
+from lcapy.current import Iname
 from lcapy.superpositionvoltage import SuperpositionVoltage
 from lcapy.superpositioncurrent import SuperpositionCurrent
 import unittest
@@ -34,20 +36,20 @@ class LcapyTester(unittest.TestCase):
                           "Voltage(Vconst(2), Vphasor(3)).is_dc")
 
     def test_voltage_add_sub_dc(self):
-        self.assertEqual2(SuperpositionVoltage(3).dc, 3, "Voltage(3).dc")
-        self.assertEqual2(SuperpositionVoltage(2, 3).dc, 5, "Voltage(2, 3).dc")
+        self.assertEqual2(SuperpositionVoltage(3).dc, voltage(3), "Voltage(3).dc")
+        self.assertEqual2(SuperpositionVoltage(2, 3).dc, voltage(5), "Voltage(2, 3).dc")
         self.assertEqual2(SuperpositionVoltage(2, 3).ac, {}, "Voltage(2, 3).ac")
-        self.assertEqual2(-SuperpositionVoltage(2).dc, -2, "-Voltage(2).dc")
+        self.assertEqual2(-SuperpositionVoltage(2).dc, voltage(-2), "-Voltage(2).dc")
         self.assertEqual2(SuperpositionVoltage(2) + SuperpositionVoltage(3), SuperpositionVoltage(5),
                           "Voltage(2) + Voltage(3)")
         self.assertEqual2(SuperpositionVoltage(2) - SuperpositionVoltage(3), SuperpositionVoltage(-1),
                           "Voltage(2) - Voltage(3)")
 
     def test_current_add_sub_dc(self):
-        self.assertEqual2(SuperpositionCurrent(3).dc, 3, "Current(3).dc")
-        self.assertEqual2(SuperpositionCurrent(2, 3).dc, 5, "Current(2, 3).dc")
+        self.assertEqual2(SuperpositionCurrent(3).dc, current(3), "Current(3).dc")
+        self.assertEqual2(SuperpositionCurrent(2, 3).dc, current(5), "Current(2, 3).dc")
         self.assertEqual2(SuperpositionCurrent(2, 3).ac, {}, "Current(2, 3).ac")
-        self.assertEqual2(-SuperpositionCurrent(2).dc, -2, "-Current(2).dc")
+        self.assertEqual2(-SuperpositionCurrent(2).dc, current(-2), "-Current(2).dc")
         self.assertEqual2(SuperpositionCurrent(2) + SuperpositionCurrent(3), SuperpositionCurrent(5),
                           "Current(2) + Current(3)")
         self.assertEqual2(SuperpositionCurrent(2) - SuperpositionCurrent(3), SuperpositionCurrent(-1),
@@ -73,11 +75,11 @@ class LcapyTester(unittest.TestCase):
     def test_voltage_transform(self):
 
         V1 = SuperpositionVoltage('3 * exp(-2 * t)')
-        self.assertEqual(V1.transform(s), 3 / (s + 2), 'transform(s)')        
+        self.assertEqual(V1.transform(s), voltage(3 / (s + 2)), 'transform(s)')        
 
         V2 = SuperpositionVoltage('3 * exp(-2 * t) * u(t)')
-        self.assertEqual(V2.transform(s), 3 / (s + 2), 'transform(s)')        
-        self.assertEqual(simplify(V2.transform(f) - 3 / (j * 2 * pi * f + 2)), 0, 'transform(f)')                
+        self.assertEqual(V2.transform(s), voltage(3 / (s + 2)), 'transform(s)')        
+        self.assertEqual(simplify(V2.transform(f) - voltage(3 / (j * 2 * pi * f + 2))), 0, 'transform(f)')                
         
     def test_voltage_subs(self):
 
@@ -89,8 +91,8 @@ class LcapyTester(unittest.TestCase):
     def test_voltage_decompose(self):
 
         V1 = SuperpositionVoltage('1 + 3 * u(t) + cos(2 * pi * 3 * t)')
-        self.assertEqual(V1.dc, 1, '.dc')
-        self.assertEqual(V1.transient, expr('3 * u(t)'), '.transient')
+        self.assertEqual(V1.dc, voltage(1), '.dc')
+        self.assertEqual(V1.transient, voltage('3 * u(t)'), '.transient')
 
     def test_voltage_oneport(self):
 
@@ -120,7 +122,7 @@ class LcapyTester(unittest.TestCase):
     def test_voltage_phasor(self):
 
         V = SuperpositionVoltage(3 * sin(7 * t) + 2 * cos(14 * t)) 
-        self.assertEqual(V[7].magnitude, expr(3), 'magnitude')
+        self.assertEqual(V[7].magnitude, voltage(3), 'magnitude')
         self.assertEqual(V[14].omega, 14, 'omega')
         
     def test_super_printing(self):
@@ -190,7 +192,6 @@ class LcapyTester(unittest.TestCase):
 
     def test_super_sympy_float(self):
 
-        V = SuperpositionVoltage()
-        V.add(sym.Float(8))
+        V = SuperpositionVoltage(sym.Float(8))
        
         self.assertEqual(isinstance(V.dc.expr, sym.Rational), True, 'Float -> Rational')
