@@ -4,8 +4,9 @@ class VoltageMixin(Quantity):
 
     quantity = 'voltage'
     quantity_label = 'Voltage'
-    units = 'V'
+    quantity_units = 'V'
     is_voltage = True
+    is_signal = True
 
     def cpt(self):
         from .oneport import V, Vac, Vdc
