@@ -7,7 +7,7 @@ Copyright 2020 Michael Hayes, UCECE
 from .ratfun import Ratfun
 from .sym import sympify, simplify, symsymbol, AppliedUndef
 from .utils import factor_const, scale_shift
-from .functions import UnitImpulse, unitimpulse, UnitStep
+from .functions import UnitImpulse, UnitStep
 import sympy as sym
 
 __all__ = ('ZT', 'IZT')
@@ -181,26 +181,76 @@ def ztransform_term(expr, n, z):
             if not delay.has(n):
                 result = invz ** delay * 1 / (1 - invz)
 
+    # cos(a * n)                
     elif expr.is_Function and expr.func == sym.cos:
         aconst, aexpr = factor_const(args[0], n)
         if aexpr == n:
             result = (1 - sym.cos(aconst) * invz) / (1 - 2 * sym.cos(aconst) * invz + invz ** 2)
 
+    # sin(a * n)
     elif expr.is_Function and expr.func == sym.sin:
         aconst, aexpr = factor_const(args[0], n)
         if aexpr == n:
-            result = (sym.sin(aconst) * invz) / (1 - 2 * sym.cos(aconst) * invz + invz ** 2)            
+            result = (sym.sin(aconst) * invz) / (1 - 2 * sym.cos(aconst) * invz + invz ** 2)
 
-    # Handle a**n
-    elif expr.is_Pow and expr.args[1] == n:
-        # TODO, handle n + m, etc.
-        result = 1 / (1 - expr.args[0] * invz)
+    # exp(a * n)
+    elif expr.is_Function and expr.func == sym.exp:
+        aconst, aexpr = factor_const(args[0], n)
+        if aexpr == n:
+            result = z / (z - sym.exp(aconst))
 
-    # Handle a**(-n)
-    elif (expr.is_Pow and expr.args[1].is_Mul and
-          expr.args[1].args[0] == -1 and expr.args[1].args[1] == n):
-        result = 1 / (1 - (1 / expr.args[0]) * invz)          
-            
+    # a**n and a**(-n)
+    elif expr.is_Pow and args[1].has(n):
+        bconst, bexpr = factor_const(args[1], n)
+        aconst = args[0] ** bconst
+        if bexpr == n:        
+            result = 1 / (1 - aconst * invz)
+
+    # n * a**n and n * a**-n        
+    elif (expr.is_Mul and len(args) == 2 and args[0] == n and
+          args[1].is_Pow and args[1].args[1].has(n)):
+
+        aconst = args[1].args[0]        
+        bconst, bexpr = factor_const(args[1].args[1], n)
+        aconst = aconst ** bconst
+        if bexpr == n:
+            result = aconst * invz / (1 - aconst * invz)**2
+
+    # n * exp(a * n)
+    elif (expr.is_Mul and len(args) == 2 and args[0] == n and
+          args[1].is_Function and args[1].func == sym.exp):
+        aconst, aexpr = factor_const(args[1].args[0], n)
+        if aexpr == n:
+            result = z * sym.exp(aconst) / (z - sym.exp(aconst))**2            
+
+    # cos(a * n) * exp(b * n) and exp(b * n) * cos(a * n)
+    elif (expr.is_Mul and args[0].is_Function and args[1].is_Function and
+          args[0].func == sym.cos and args[1].func == sym.exp):    
+        aconst, aexpr = factor_const(args[0].args[0], n)
+        bconst, bexpr = factor_const(args[1].args[0], n)
+        if aexpr == n and bexpr == n:
+            num = z * (z - sym.exp(aconst) * sym.cos(bconst))
+            den = (z**2 - 2 * z * sym.exp(aconst) * sym.cos(bconst) + sym.exp(2 * aconst))
+            result = num / den
+
+    # sin(a * n) * exp(b * n) and exp(b * n) * sin(a * n)
+    elif (expr.is_Mul and args[0].is_Function and args[1].is_Function and
+          args[0].func == sym.exp and args[1].func == sym.sin):
+        aconst, aexpr = factor_const(args[1].args[0], n)
+        bconst, bexpr = factor_const(args[0].args[0], n)
+        if aexpr == n and bexpr == n:
+            num = z * sym.exp(aconst) * sym.sin(bconst)
+            den = (z**2 - 2 * z * sym.exp(aconst) * sym.cos(bconst) + sym.exp(2 * aconst))
+            result = num / den
+
+    # exp(a * n) * exp(b * n)
+    elif (expr.is_Mul and args[0].is_Function and args[1].is_Function and
+          args[0].func == sym.exp and args[1].func == sym.exp):
+        aconst, aexpr = factor_const(args[1].args[0], n)
+        bconst, bexpr = factor_const(args[0].args[0], n)
+        if aexpr == n and bexpr == n:
+            result = z / (z - sym.exp(aconst + bconst))            
+        
     if result is None:
         # Use m instead of n to avoid n and z in same expr.
         # TODO, check if m already used...
@@ -317,7 +367,7 @@ def inverse_ztransform_ratfun(expr, z, n, **assumptions):
         Qpoly = sym.Poly(Q, z)        
         C = Qpoly.all_coeffs()
         for m, c in enumerate(C):
-            cresult += c * unitimpulse(n - len(C) + m + 1)
+            cresult += c * UnitImpulse(n - len(C) + m + 1)
 
     # There is problem with determining residues if
     # have 1/(z*(-a/z + 1)) instead of 1/(-a + z).  Hopefully,
@@ -350,7 +400,7 @@ def inverse_ztransform_ratfun(expr, z, n, **assumptions):
             # See laplace.py
 
             if p == 0:
-                cresult += r * unitimpulse(n)
+                cresult += r * UnitImpulse(n)
             else:
                 uresult += r * p ** n
             continue
@@ -365,9 +415,9 @@ def inverse_ztransform_ratfun(expr, z, n, **assumptions):
                 sym.diff(expr2, z, m), z, p) / sym.factorial(m)
 
             if p == 0:
-                cresult += r * unitimpulse(n - i + 1)
+                cresult += r * UnitImpulse(n - i + 1)
             else:            
-                uresult += r * (p ** n) * n**(i - 1)
+                uresult += r * (p ** (n - 1)) * n**(i - 1)
 
     # cresult is a sum of Dirac deltas and its derivatives so is known
     # to be causal.
@@ -475,8 +525,9 @@ def inverse_ztransform_product(expr, z, n, **assumptions):
         intnum += 1
         cresult, uresult = inverse_ztransform_term1(factors[m + 1], z, n)
         expr2 = cresult + uresult
-        result = sym.Sum(result.subs(n, n - dummy) * expr2.subs(n, dummy),
-                         (dummy, n1, n2))
+        kernel = result.subs(n, n - dummy) * expr2.subs(n, dummy)
+        sresult = sym.Sum(kernel, (dummy, n1, n2))
+        result = sresult
     
     return const * result
 
@@ -492,7 +543,7 @@ def inverse_ztransform_power(expr, z, n, **assumptions):
         elif not exponent.is_negative:
             print('Warning, dodgy z-transform.  May have advance of unit impulse.')
         
-        return unitimpulse(n + exponent), sym.S.Zero
+        return UnitImpulse(n + exponent), sym.S.Zero
 
     # Handle expressions with a power of (1 / z).
     if (expr.is_Pow and expr.args[0].is_Pow and
@@ -505,7 +556,7 @@ def inverse_ztransform_power(expr, z, n, **assumptions):
         elif not exponent.is_positive:
             print('Warning, dodgy z-transform.  May have advance of unit impulse.')
         
-        return unitimpulse(n - exponent), sym.S.Zero        
+        return UnitImpulse(n - exponent), sym.S.Zero        
 
     raise ValueError('Expression %s is not a power of z' % expr)
 
@@ -527,7 +578,7 @@ def inverse_ztransform_term1(expr, z, n, **assumptions):
     const, expr = factor_const(expr, z)
 
     if expr == 1:
-        return const * unitimpulse(n), sym.S.Zero
+        return const * UnitImpulse(n), sym.S.Zero
     
     if isinstance(expr, AppliedUndef):
         # Handle V(z), 3 * V(z) etc.  If causal is True it is assumed
@@ -542,7 +593,7 @@ def inverse_ztransform_term1(expr, z, n, **assumptions):
 
     if expr == z:
         print('Warning, dodgy z-transform.  Have advance of unit impulse.') 
-        return const * unitimpulse(n + 1), sym.S.Zero        
+        return const * UnitImpulse(n + 1), sym.S.Zero        
 
     if (expr.is_Pow and
         (expr.args[0] == z or
@@ -594,6 +645,7 @@ def inverse_ztransform_by_terms(expr, z, n, **assumptions):
 def inverse_ztransform_make(n, const, cresult, uresult, **assumptions):
 
     result = const * (cresult + uresult)
+    result = result.simplify()
     
     if assumptions.get('dc', False):
         free_symbols = set([symbol.name for symbol in result.free_symbols])
